@@ -80,13 +80,8 @@ class Api42():
     
     
     def close(self):
-        del self.client_id
-        del self.client_secret
-        del self.scope
-        del self.api_url
         self.session.close()
-        del self.session
-        del self.processes
+
 
     
     # ------------------- GET TOKEN ------------------- #
